==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/pt_br/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Novo';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspenso';
$lang['AdminMain.graph_line_name.canceled'] = 'Cancelado';
$lang['AdminMain.graph_line_name.active'] = 'Ativo';
$lang['AdminMain.graph_name.graph_clients'] = 'Clientes';
$lang['AdminMain.graph_name.graph_services'] = 'Serviços';
$lang['AdminMain.settings.submit_settings'] = 'Atualizar configurações';
$lang['AdminMain.settings.submit_cancel'] = 'Retornar à visão geral';
$lang['AdminMain.settings.date_range'] = 'Intervalo de datas do gráfico';
$lang['AdminMain.settings.show_legend'] = 'Mostrar legenda';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Não separa mais os gráficos em guias, mas mostra todos eles em uma única guia.';
$lang['AdminMain.settings.show_one_tab'] = 'Mostrar apenas uma guia';
$lang['AdminMain.settings.heading_settings'] = 'Configurações';
$lang['AdminMain.settings.graph_services'] = 'Gráfico de serviços';
$lang['AdminMain.settings.text_graphs_services'] = 'Verifique quais gráficos devem aparecer na guia Serviços.';
$lang['AdminMain.settings.heading_services'] = 'Guia Serviços';
$lang['AdminMain.settings.graph_clients'] = 'Gráfico de clientes';
$lang['AdminMain.settings.text_graphs_clients'] = 'Verifique quais gráficos devem aparecer na guia Clientes.';
$lang['AdminMain.settings.heading_clients'] = 'Guia Clientes';
$lang['AdminMain.settings.pending_orders'] = 'Ordens pendentes';
$lang['AdminMain.settings.open_tickets'] = 'Ingressos abertos';
$lang['AdminMain.settings.recurring_invoices'] = 'Faturas recorrentes';
$lang['AdminMain.settings.active_users_today'] = 'Usuários ativos hoje';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Serviços programados para cancelamento';
$lang['AdminMain.settings.services_active'] = 'Serviços ativos';
$lang['AdminMain.settings.clients_active'] = 'Clientes ativos';
$lang['AdminMain.settings.text_options'] = 'Verifique as opções que aparecerão na Visão geral do sistema.';
$lang['AdminMain.settings.heading_statistics'] = 'Estatísticas';
$lang['AdminMain.date_range.days'] = '%1$s Dias';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutos atrás';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minuto atrás';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Agora mesmo';
$lang['AdminMain.overview.tooltip_location'] = 'Localização';
$lang['AdminMain.overview.tooltip_activity'] = 'Última atividade';
$lang['AdminMain.overview.tab_services'] = 'Serviços';
$lang['AdminMain.overview.tab_clients'] = 'Clientes';
$lang['AdminMain.overview.tab_all'] = 'Gráficos';
$lang['AdminMain.overview.heading_users'] = 'Usuários recentes';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Ingressos abertos';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Ordens pendentes';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Faturas recorrentes';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Usuários ativos hoje';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Serviços programados para cancelamento';
$lang['AdminMain.overview.statistic.services_active'] = 'Serviços ativos';
$lang['AdminMain.overview.statistic.clients_active'] = 'Clientes ativos';
$lang['AdminMain.index.boxtitle_overview'] = 'Visão geral do sistema';
$lang['AdminMain.!success.options_updated'] = 'As configurações da Visão geral do sistema foram atualizadas com sucesso!';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/pt_br/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.pt_br
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.new'] = 'Novo';
$lang['AdminMain.graph_line_name.suspended'] = 'Suspenso';
$lang['AdminMain.graph_line_name.canceled'] = 'Cancelado';
$lang['AdminMain.graph_line_name.active'] = 'Ativo';
$lang['AdminMain.graph_name.graph_clients'] = 'Clientes';
$lang['AdminMain.graph_name.graph_services'] = 'Serviços';
$lang['AdminMain.settings.submit_settings'] = 'Atualizar configurações';
$lang['AdminMain.settings.submit_cancel'] = 'Retornar à visão geral';
$lang['AdminMain.settings.date_range'] = 'Intervalo de datas do gráfico';
$lang['AdminMain.settings.show_legend'] = 'Mostrar legenda';
$lang['AdminMain.settings.tooltip_show_one_tab'] = 'Não separa mais os gráficos em guias, mas mostra todos eles em uma única guia.';
$lang['AdminMain.settings.show_one_tab'] = 'Mostrar apenas uma guia';
$lang['AdminMain.settings.heading_settings'] = 'Configurações';
$lang['AdminMain.settings.graph_services'] = 'Gráfico de serviços';
$lang['AdminMain.settings.text_graphs_services'] = 'Verifique quais gráficos devem aparecer na guia Serviços.';
$lang['AdminMain.settings.heading_services'] = 'Guia Serviços';
$lang['AdminMain.settings.graph_clients'] = 'Gráfico de clientes';
$lang['AdminMain.settings.text_graphs_clients'] = 'Verifique quais gráficos devem aparecer na guia Clientes.';
$lang['AdminMain.settings.heading_clients'] = 'Guia Clientes';
$lang['AdminMain.settings.pending_orders'] = 'Ordens pendentes';
$lang['AdminMain.settings.open_tickets'] = 'Ingressos abertos';
$lang['AdminMain.settings.recurring_invoices'] = 'Faturas recorrentes';
$lang['AdminMain.settings.active_users_today'] = 'Usuários ativos hoje';
$lang['AdminMain.settings.services_scheduled_cancellation'] = 'Serviços programados para cancelamento';
$lang['AdminMain.settings.services_active'] = 'Serviços ativos';
$lang['AdminMain.settings.clients_active'] = 'Clientes ativos';
$lang['AdminMain.settings.text_options'] = 'Verifique as opções que aparecerão na Visão geral do sistema.';
$lang['AdminMain.settings.heading_statistics'] = 'Estatísticas';
$lang['AdminMain.date_range.days'] = '%1$s Dias';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s minutos atrás';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 minuto atrás';
$lang['AdminMain.overview.tooltip_last_activity_now'] = 'Agora mesmo';
$lang['AdminMain.overview.tooltip_location'] = 'Localização';
$lang['AdminMain.overview.tooltip_activity'] = 'Última atividade';
$lang['AdminMain.overview.tab_services'] = 'Serviços';
$lang['AdminMain.overview.tab_clients'] = 'Clientes';
$lang['AdminMain.overview.tab_all'] = 'Gráficos';
$lang['AdminMain.overview.heading_users'] = 'Usuários recentes';
$lang['AdminMain.overview.statistic.open_tickets'] = 'Ingressos abertos';
$lang['AdminMain.overview.statistic.pending_orders'] = 'Ordens pendentes';
$lang['AdminMain.overview.statistic.recurring_invoices'] = 'Faturas recorrentes';
$lang['AdminMain.overview.statistic.active_users_today'] = 'Usuários ativos hoje';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = 'Serviços programados para cancelamento';
$lang['AdminMain.overview.statistic.services_active'] = 'Serviços ativos';
$lang['AdminMain.overview.statistic.clients_active'] = 'Clientes ativos';
$lang['AdminMain.index.boxtitle_overview'] = 'Visão geral do sistema';
$lang['AdminMain.!success.options_updated'] = 'As configurações da Visão geral do sistema foram atualizadas com sucesso!';
$lang['AdminMain.date_range.month'] = 'Mês atual';
$lang['AdminMain.date_range.day'] = '1 dia';
$lang['AdminMain.date_range.ytd'] = 'Ano até a data';
